##################
#import data
setwd("/home/mazerolm/Documents/Stats consulting/Occupancy Workshops/Day2")
setwd("C:/Users/Mazerolle/Desktop/Exercice")
occ.df <- read.table("Exercice.txt", header = TRUE)
head(occ.df)
str(occ.df)

##center Conifer.cover
occ.df$Conifer.cover.cent <- occ.df$Conifer.cover - mean(occ.df$Conifer.cover)
##center Age
occ.df$Age.cent <- occ.df$Age - mean(occ.df$Age)
##center Effort
Effort <- occ.df[, c("Effort1", "Effort2", "Effort3")]
mean.effort <- mean(as.vector(as.matrix(Effort)))
Effort.cent <- Effort - mean.effort


library(unmarked)
occu.dat <- unmarkedFrameOccu(y = occ.df[, c("V1", "V2", "V3")],
                              siteCovs = occ.df[, c("Treatment",
                                "Conifer.cover.cent", "Age.cent")],
                              obsCovs = list(
                                Effort.cent = Effort.cent))
summary(occu.dat)

##check correlations
cor(occ.df[, c("Conifer.cover.cent", "Age.cent")])
boxplot(Conifer.cover.cent ~ Treatment, data = occ.df)
boxplot(Age.cent ~ Treatment, data = occ.df)

##null
m0 <- occu(~ 1 ~ 1, data = occu.dat)
##psi(Conifer+Age) p(Effort)
m1 <- occu(~ Effort.cent ~ Conifer.cover.cent + Age.cent,
           data = occu.dat)
##psi(Treat) p(Effort)
m2 <- occu(~ Effort.cent ~ Treatment + Age.cent,
           data = occu.dat)
##psi(Conifer+Age) p(Effort+Treat)
m3 <- occu(~ Effort.cent + Treatment ~ Conifer.cover.cent + Age.cent,
           data = occu.dat)
##psi(Treat) p(Effort+Treat)
m4 <- occu(~ Effort.cent + Treatment ~ Treatment,
           data = occu.dat)


##set up models in list
My.mods <- list(m0, m1, m2, m3, m4)
My.names <- c("null", "psi(Con+Age)p(Eff)",
              "psi(Treat)p(Eff)", "psi(Con+Age)p(Eff+Treat)",
              "psi(Treat)p(Eff+Treat)")

library(AICcmodavg)
aictab(cand.set = My.mods, modnames = My.names)
##m3 has Akaike weight of 0.97

##check fit of m3
mb.gof.test(m3, nsim = 100)


##on psi
##Conifer cover
modavg(cand.set = My.mods, modnames = My.names,
       parm = "Conifer.cover.cent",
       parm.type = "psi")
##Age
print(modavg(cand.set = My.mods, modnames = My.names,
       parm = "Age.cent",
       parm.type = "psi"), digits = 4)
##Treat
modavg(cand.set = My.mods, modnames = My.names,
       parm = "TreatmentEC",
       parm.type = "psi")

###############
##on p
##Treatment
modavg(cand.set = My.mods, modnames = My.names,
       parm = "TreatmentEC",
       parm.type = "detect")
##Effort
modavg(cand.set = My.mods, modnames = My.names,
       parm = "Effort.cent",
       parm.type = "detect")


##prediction on occupancy of first site
pred.site1 <- modavgpred(cand.set = My.mods,
                         modnames = My.names,
                         newdata = occ.df[1, ],
                         type = "response",
                         parm.type = "psi")
##compute lower and upper 95%CI limits
pred.site1.logit <- modavgpred(cand.set = My.mods,
                               modnames = My.names,
                               newdata = occ.df[1, ],
                               type = "link",
                               parm.type = "psi")

upp95 <- plogis(pred.site1.logit$mod.avg.pred + 1.96*pred.site1.logit$uncond.se)
low95 <- plogis(pred.site1.logit$mod.avg.pred - 1.96*pred.site1.logit$uncond.se)

##display result
cat("\nModel-averaged psi for site 1: ", pred.site1$mod.avg.pred, "\n\n",
    "95% CI:", low95, ", ", upp95, "\n\n")
    
